#include "opencv2/opencv.hpp"

using namespace cv;
using namespace std;

float Multiplier = 0.5;

float noise1Mean = 8.0;
float noise1Sigma = 60.0;

double sigma_x = 5.0;
double sigma_y = 5.0;

float noise2Mean = 0.0;
float noise2Sigma = 6.0;

void addNoise(Mat &Image, float mu, float sigma, uint64 seed) {
	Mat NoiseMat(Image.rows, Image.cols, Image.type());
	RNG rng(seed);
	rng.fill(NoiseMat, cv::RNG::NORMAL, mu, sigma);
	Image += NoiseMat;
}

unsigned int generateHash(std::string inputString) {
	const char * myStr = inputString.c_str();
	size_t len = inputString.length();
	
	unsigned int hash = 0;
	for(size_t i = 0; i < len; ++i) 
		hash = 65599 * hash + myStr[i];
	return hash ^ (hash >> 16);
}

int main(int argc, char** argv) {
     //This program is to be called with a single parameter: the absolute path of an image to be corrupted
     
     if (argc < 2) {
     	fprintf(stderr,"This program must be called with a command-line argument: the absolute path of the image to be corrupted.");
     	return(-1);
     }
     string path(argv[1]);
     Mat Image_Uint = imread(path.c_str());
     Mat Image;
     
     uint64 seed = (uint64) generateHash(path);
     
     Image_Uint.convertTo(Image, CV_32F);
     
     //First, darken and add noise
     Image = Image * Multiplier;
     addNoise(Image, noise1Mean, noise1Sigma, seed++);
     
     //Blur Image
     GaussianBlur(Image, Image, Size(0,0), sigma_x, sigma_y);
     
     //Add more noise
     addNoise(Image, noise2Mean, noise2Sigma, seed++);
     
     //Save image
     imwrite(path.c_str(), Image);
}
