//This module provides classes for loading and saving video data with or without between-frame
//rotation matrices. Saved data is frame-accurate. That is, if an image is saved as frame n,
//then when frame n is retrieved, it will be the same image that was previously saved.
//Whether frame numbers are 0 or 1 indexed is not important, so long as the same convention
//is used both when loading and saving data. Frame numbers must always be non-negative.

#pragma once
#include <eigen3/Eigen/Eigen>
#include "opencv2/opencv.hpp"
#include <string>

class rawDataSaver {
	public:
		rawDataSaver();
		int init(std::string DataFolderPath);
		int saveFrame(int frameNumber, cv::Mat &frame);
		int saveRotation(int startFrameNumber, int endFrameNumber, Eigen::Matrix3d &R);
		
		std::string getNextAvailableFolderPath(std::string basePath);
	private:
		std::string folderPath;
		bool isInitialized;
};

class rawDataLoader {
	public:
		rawDataLoader();
		int init(std::string DataFolderPath);
		int getNumberOfFramesAvailable(void);
		bool containsRotations(void);
		
		int getFrame(int frameNumber, cv::Mat &frame);
		int getRotation(int startFrameNumber, int endFrameNumber, Eigen::Matrix3d &R);
	private:
		std::string folderPath;
		int numberOfFramesAvailable;
		bool allRotationsPresent;
		bool isInitialized;
};
